---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Bug Description**
A clear and concise description of the bug.

**Expected Behavior**
What you expected to happen.

**Steps To Reproduce**
1. 

**Environment**
 - Package Version: 
 - Python Version: 
 - OS: 

**Additional Context**
Any additional information.

**Screenshots**
If applicable, add screenshots to help explain your problem.
